@@ -4,28 +4,29 @@ Graphora Client
 Main client class for interacting with the Graphora API.
 """
 
-import os
-import requests
 import json
+import os
 import time
-from typing import Dict, List, Optional, Union, BinaryIO, Any
+import warnings
 from pathlib import Path
+from typing import Any, BinaryIO, Dict, List, Optional, Union
+
+import requests
 
 from graphora.models import (
     OntologyResponse,
     TransformResponse,
     TransformStatus,
-    MergeResponse,
-    MergeStatus,
+    TransformRunStatus,
+    MergeInitResponse,
+    MergeState,
     GraphResponse,
     DocumentMetadata,
-    ConflictResolution,
+    ChangeLog,
     ResolutionStrategy,
     SaveGraphRequest,
     SaveGraphResponse,
-    # Quality models
     QualityResults,
-    QualityViolation,
     QualityRuleType,
     QualitySeverity,
     ApprovalRequest,
@@ -35,9 +36,14 @@ from graphora.models import (
     QualityViolationsResponse,
     QualitySummaryResponse,
     QualityDeleteResponse,
-    QualityHealthResponse
+    QualityHealthResponse,
+    RecentRunsResponse,
+    DashboardSummaryResponse,
+    DashboardPerformanceResponse,
+    DashboardQualityResponse,
 )
 from graphora.exceptions import GraphoraAPIError, GraphoraClientError
+from graphora.utils import get_api_url
 
 
 class GraphoraClient:
@@ -54,35 +60,50 @@ class GraphoraClient:
     
     def __init__(
         self,
-        base_url: str,
-        user_id: str,
-        api_key: Optional[str] = None,
-        timeout: int = 60
+        base_url: Optional[str] = None,
+        auth_token: Optional[str] = None,
+        user_id: Optional[str] = None,
+        timeout: int = 60,
     ):
         """
         Initialize a new Graphora client.
         
         Args:
-            base_url: Base URL of the Graphora API (e.g., "https://api.graphora.example.com")
-            user_id: User's ID (required for all API calls)
-            api_key: Optional API key for authentication
+            base_url: Base URL of the Graphora API. If omitted, the client uses the
+                `GRAPHORA_API_URL` environment variable or the value derived from
+                `graphora.utils.get_api_url()`.
+            auth_token: Clerk-issued bearer token for authentication. If not provided,
+                the client will read GRAPHORA_AUTH_TOKEN from the environment.
+            user_id: Optional user identifier for client-side bookkeeping (not sent automatically)
             timeout: Request timeout in seconds
         """
-        self.base_url = base_url.rstrip('/')
+        resolved_base_url = base_url or os.environ.get("GRAPHORA_API_URL") or get_api_url()
+        self.base_url = resolved_base_url.rstrip('/')
+        env_token = os.environ.get("GRAPHORA_AUTH_TOKEN")
+        self.auth_token = auth_token or env_token
+        if not self.auth_token:
+            raise ValueError(
+                "A Clerk bearer token is required. Provide it via auth_token="
+                " or the GRAPHORA_AUTH_TOKEN environment variable."
+            )
+        if os.environ.get("GRAPHORA_API_KEY") and not auth_token:
+            warnings.warn(
+                "GRAPHORA_API_KEY is deprecated; use GRAPHORA_AUTH_TOKEN instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
         self.user_id = user_id
-        self.api_key = api_key or os.environ.get("GRAPHORA_API_KEY")
         self.timeout = timeout
         self.api_version = "v1"
-        
+
     @property
     def headers(self) -> Dict[str, str]:
         """Get headers for API requests."""
         headers = {
             "Accept": "application/json",
-            "user-id": self.user_id  # Add user-id header to all requests
         }
-        if self.api_key:
-            headers["Authorization"] = f"Bearer {self.api_key}"
+        if self.auth_token:
+            headers["Authorization"] = f"Bearer {self.auth_token}"
         return headers
     
     def _build_url(self, endpoint: str) -> str:
@@ -90,6 +111,12 @@ class GraphoraClient:
         if endpoint.startswith("/"):
             endpoint = endpoint[1:]
         return f"{self.base_url}/api/{self.api_version}/{endpoint}"
+
+    def _build_system_url(self, path: str) -> str:
+        """Build URL for system-level endpoints that are not versioned."""
+        if not path.startswith("/"):
+            path = "/" + path
+        return f"{self.base_url}{path}"
     
     def _handle_response(self, response: requests.Response) -> Dict[str, Any]:
         """Handle API response and raise appropriate exceptions."""
@@ -164,32 +191,34 @@ class GraphoraClient:
         """
         url = self._build_url(f"transform/{ontology_id}/upload")
         
-        # Prepare files for upload
-        upload_files = []
+        multipart_files: List[Any] = []
+        opened_files: List[BinaryIO] = []
         for i, file in enumerate(files):
             if isinstance(file, (str, Path)):
                 path = Path(file)
                 filename = path.name
                 file_obj = open(path, "rb")
+                opened_files.append(file_obj)
             else:
-                # Assume file-like object
                 filename = getattr(file, "name", f"file_{i}")
                 file_obj = file
-                
-            upload_files.append(("files", (filename, file_obj)))
-        
-        response = requests.post(
-            url,
-            files=upload_files,
-            headers=self.headers,
-            timeout=self.timeout
-        )
-        
-        # Close file objects if we opened them
-        for _, (_, file_obj) in upload_files:
-            if isinstance(files[_], (str, Path)):
-                file_obj.close()
-        
+
+            multipart_files.append(("files", (filename, file_obj)))
+
+        try:
+            response = requests.post(
+                url,
+                files=multipart_files,
+                headers=self.headers,
+                timeout=self.timeout,
+            )
+        finally:
+            for fh in opened_files:
+                try:
+                    fh.close()
+                except Exception:  # pragma: no cover - best effort cleanup
+                    pass
+
         result = self._handle_response(response)
         return TransformResponse(**result)
     
@@ -237,7 +266,10 @@ class GraphoraClient:
         start_time = time.time()
         while time.time() - start_time < timeout:
             status = self.get_transform_status(transform_id)
-            if status.status in ["COMPLETED", "FAILED"]:
+            if status.overall_status in (
+                TransformRunStatus.COMPLETED,
+                TransformRunStatus.FAILED,
+            ):
                 return status
             time.sleep(poll_interval)
         
@@ -253,10 +285,10 @@ class GraphoraClient:
         Returns:
             True if cleanup was successful
         """
-        url = self._build_url(f"transform/cleanup/{transform_id}")
-        response = requests.delete(url, headers=self.headers, timeout=self.timeout)
-        result = self._handle_response(response)
-        return result.get("success", False)
+        url = self._build_url(f"transform/status/{transform_id}/cleanup")
+        response = requests.post(url, headers=self.headers, timeout=self.timeout)
+        self._handle_response(response)
+        return True
     
     def get_transformed_graph(
         self,
@@ -297,7 +329,10 @@ class GraphoraClient:
             SaveGraphResponse with updated graph data
         """
         url = self._build_url(f"graph/{transform_id}")
-        response = requests.put(url, json=changes.dict(), headers=self.headers, timeout=self.timeout)
+        payload = changes.model_dump(exclude_none=True)
+        response = requests.put(
+            url, json=payload, headers=self.headers, timeout=self.timeout
+        )
         result = self._handle_response(response)
         return SaveGraphResponse(**result)
     
@@ -307,8 +342,8 @@ class GraphoraClient:
         self,
         session_id: str,
         transform_id: str,
-        merge_id: Optional[str] = None
-    ) -> MergeResponse:
+        merge_id: Optional[str] = None,
+    ) -> MergeInitResponse:
         """
         Start a new merge process.
         
@@ -318,7 +353,7 @@ class GraphoraClient:
             merge_id: Optional custom merge ID
             
         Returns:
-            MergeResponse with the ID for tracking progress
+            MergeInitResponse with the ID for tracking progress
         """
         url = self._build_url(f"merge/{session_id}/{transform_id}/start")
         params = {}
@@ -327,9 +362,9 @@ class GraphoraClient:
             
         response = requests.post(url, params=params, headers=self.headers, timeout=self.timeout)
         result = self._handle_response(response)
-        return MergeResponse(**result)
+        return MergeInitResponse(**result)
     
-    def get_merge_status(self, merge_id: str) -> MergeStatus:
+    def get_merge_status(self, merge_id: str) -> MergeState:
         """
         Get the status of a merge process.
         
@@ -342,9 +377,13 @@ class GraphoraClient:
         url = self._build_url(f"merge/{merge_id}/status")
         response = requests.get(url, headers=self.headers, timeout=self.timeout)
         result = self._handle_response(response)
-        return MergeStatus(**result)
+        if isinstance(result, str):
+            return MergeState(result)
+        raise GraphoraClientError(
+            f"Unexpected merge status payload for {merge_id}: {result}"
+        )
     
-    def get_conflicts(self, merge_id: str) -> List[ConflictResolution]:
+    def get_conflicts(self, merge_id: str) -> List[ChangeLog]:
         """
         Get conflicts for a merge process.
         
@@ -357,7 +396,7 @@ class GraphoraClient:
         url = self._build_url(f"merge/{merge_id}/conflicts")
         response = requests.get(url, headers=self.headers, timeout=self.timeout)
         result = self._handle_response(response)
-        return [ConflictResolution(**item) for item in result]
+        return [ChangeLog(**item) for item in result]
     
     def resolve_conflict(
         self,
@@ -381,10 +420,11 @@ class GraphoraClient:
             True if the resolution was applied successfully
         """
         url = self._build_url(f"merge/{merge_id}/conflicts/{conflict_id}/resolve")
+        resolution_value = resolution.value if isinstance(resolution, ResolutionStrategy) else resolution
         data = {
             "changed_props": changed_props,
-            "resolution": resolution,
-            "learning_comment": learning_comment
+            "resolution": resolution_value,
+            "learning_comment": learning_comment,
         }
         response = requests.post(url, json=data, headers=self.headers, timeout=self.timeout)
         result = self._handle_response(response)
@@ -561,3 +601,69 @@ class GraphoraClient:
         response = requests.get(url, timeout=self.timeout)  # No auth headers needed for health check
         result = self._handle_response(response)
         return QualityHealthResponse(**result)
+
+    # Dashboard Endpoints
+
+    def get_dashboard_runs(
+        self,
+        limit: int = 20,
+        days: int = 14
+    ) -> RecentRunsResponse:
+        """Fetch the most recent transform runs with quality and usage context."""
+
+        url = self._build_url("dashboard/runs")
+        params = {
+            "limit": min(max(limit, 1), 50),
+            "days": min(max(days, 1), 90)
+        }
+        response = requests.get(url, params=params, headers=self.headers, timeout=self.timeout)
+        result = self._handle_response(response)
+        return RecentRunsResponse(**result)
+
+    def get_dashboard_summary(
+        self,
+        days: int = 14,
+        max_runs: int = 200
+    ) -> DashboardSummaryResponse:
+        """Retrieve aggregated KPI metrics for the dashboard summary header."""
+
+        url = self._build_url("dashboard/summary")
+        params = {
+            "days": min(max(days, 1), 90),
+            "max_runs": min(max(max_runs, 1), 1000)
+        }
+        response = requests.get(url, params=params, headers=self.headers, timeout=self.timeout)
+        result = self._handle_response(response)
+        return DashboardSummaryResponse(**result)
+
+    def get_dashboard_performance(
+        self,
+        days: int = 14,
+        max_runs: int = 200
+    ) -> DashboardPerformanceResponse:
+        """Retrieve performance time-series metrics for dashboard charts."""
+
+        url = self._build_url("dashboard/performance")
+        params = {
+            "days": min(max(days, 1), 90),
+            "max_runs": min(max(max_runs, 1), 1000)
+        }
+        response = requests.get(url, params=params, headers=self.headers, timeout=self.timeout)
+        result = self._handle_response(response)
+        return DashboardPerformanceResponse(**result)
+
+    def get_dashboard_quality(
+        self,
+        days: int = 14,
+        max_runs: int = 200
+    ) -> DashboardQualityResponse:
+        """Retrieve quality aggregates for the dashboard quality section."""
+
+        url = self._build_url("dashboard/quality")
+        params = {
+            "days": min(max(days, 1), 90),
+            "max_runs": min(max(max_runs, 1), 1000)
+        }
+        response = requests.get(url, params=params, headers=self.headers, timeout=self.timeout)
+        result = self._handle_response(response)
+        return DashboardQualityResponse(**result)
